Crate tri_macros

Crate tri_macros 

Attribute Macros

time_event
times an event and adds it to the function tree, takes a reference to a profiler static and a str name
time_lone_function
times an event without adding it to the function tree, can be viewed in PerformanceProfiler::list_all_functions takes a reference to a profiler static and a str name