Attribute Macros
- time_
event - times an event and adds it to the function tree, takes a reference to a profiler static and a str name
- time_
lone_ function - times an event without adding it to the function tree,
can be viewed in
PerformanceProfiler::list_all_functionstakes a reference to a profiler static and a str name